# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

%global upstream_version 1.201
%global extra_version 0

Name:		perl-Algorithm-Diff
Version:	%{upstream_version}%{?extra_version}
Release:	8.%{__distinit}%{__distvers}
Summary:	Compute 'intelligent' differences between two files/lists
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Algorithm-Diff
Source0:	https://cpan.metacpan.org/modules/by-module/Algorithm/Algorithm-Diff-%{upstream_version}.tar.gz
Patch0:		Algorithm-Diff-1.1903-provides.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(warnings)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(integer)
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
# Test Suite
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(lib)
BuildRequires:	perl(Test)
# Runtime
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Carp)

%description
This is a module for computing the difference between two files, two strings,
or any other two lists of things. It uses an intelligent algorithm similar to
(or identical to) the one used by the Unix "diff" program. It is guaranteed to
find the *smallest possible* set of differences.

%prep
%setup -q -n Algorithm-Diff-%{upstream_version}

# Generate provide for perl(Algorithm::DiffOld)
%patch0

# Make scripts executable
chmod -c +x bin/cdiff.pl bin/diff.pl bin/diffnew.pl bin/htmldiff.pl

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc Changes README bin/*.pl
%{perl_vendorlib}/Algorithm/
%{_mandir}/man3/Algorithm::Diff.3*
%{_mandir}/man3/Algorithm::DiffOld.3*

%changelog
* Mon Mar  6 2023 Paul Howarth <paul@city-fan.org> - 1.2010-8
- Use SPDX-format license tag

* Mon Dec 14 2020 Paul Howarth <paul@city-fan.org> - 1.2010-1
- Update to 1.201
  - Speed up LCS when $keyGen is undef (CPAN RT#101105)
- Sample scripts shipped as documentation rather than under Perl vendor directory

* Mon Sep 28 2020 Paul Howarth <paul@city-fan.org> - 1.2000-1
- Update to 1.200
  - New release with no new features, just preparing for a series of bugfix
    releases

* Thu May 30 2019 Paul Howarth <paul@city-fan.org> - 1.1903-13
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop explicit buildroot cleaning in %%install section
- Drop explicit %%clean section
- Drop legacy BuildRoot: and Group: tags
- Switch upstream from search.cpan.org to metacpan.org

* Thu Aug  4 2016 Paul Howarth <paul@city-fan.org> - 1.1903-5
- BR: perl-generators where available
- Simplify find command using -delete

* Sat Jun  6 2015 Paul Howarth <paul@city-fan.org> - 1.1903-2
- Perl 5.22 rebuild

* Wed Nov 26 2014 Paul Howarth <paul@city-fan.org> - 1.1903-1
- Update to 1.1903
  - Fix documentation typos (CPAN RT#84981)
  - Add -w and -i switches to diffnew.pl (CPAN RT#69945)
  - Remove Algorithm::DiffOld from the index; the module is still distributed
    with Algorithm::Diff, but is not indexed on CPAN because this is an
    ***UNAUTHORIZED*** release of Algorithm::DiffOld
- Add patch to generate provide for perl(Algorithm::DiffOld)
- Drop %%defattr, redundant since rpm 4.4

* Thu Jun  7 2012 Paul Howarth <paul@city-fan.org> - 1.1902-14
- BR: perl(Data::Dumper) and perl(Exporter)
- Don't need to remove empty directories from buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Tue Jun 21 2011 Paul Howarth <paul@city-fan.org> - 1.1902-13
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 1.1902-7
- Rebuild for perl 5.12.1 in Rawhide

* Fri May 28 2010 Paul Howarth <paul@city-fan.org> - 1.1902-6
- Fix dist tag for RHEL-6 Beta

* Fri Feb 19 2010 Paul Howarth <paul@city-fan.org> - 1.1902-5
- Dist tag for Rawhide no longer needs special-casing

* Thu Sep  3 2009 Paul Howarth <paul@city-fan.org> 1.1902-4
- Define RPM macros in global scope

* Wed Nov  5 2008 Paul Howarth <paul@city-fan.org> - 1.1902-3
- BuildRequire perl(ExtUtils::MakeMaker)
- Tweak dist tag macros to work on current Rawhide with three-part releasenum
- Clarify license as GPL version 1 or later, or Artistic (i.e. same as perl)

* Fri Sep  1 2006 Paul Howarth <paul@city-fan.org> - 1.1902-2
- Fix distribution tags for development releases

* Mon Jul 31 2006 Paul Howarth <paul@city-fan.org> - 1.1902-1
- Update to 1.1902
- Simplify distribution-detection
- Remove macro %%{__perl_version}, used only once
- Remove macro %%{__perl_package}, used only twice
- Define %%{__id_u} in a more portable way
- Use search.cpan.org URLs
- Don't use macros in command paths, hardcode them instead
- Clear buildroot unconditionally in %%clean and %%install
- Don't bother setting compiler flags for noarch package
- Make example scripts executable

* Sat Jun  4 2005 Paul Howarth <paul@city-fan.org> - 1.1901-2
- Rewrite spec file in (mainly) Fedora Extras style
- Include full URL for source
- Fix URL
- Use MODULE_COMPAT dependency style and remove explicit perl dependency
- Remove MANIFEST from %%doc

* Wed Oct 27 2004 Paul Howarth <paul@city-fan.org> - 1.1901-1
- Update to 1.1901
- Tidy up spec file

* Mon May 10 2004 Paul Howarth <paul@city-fan.org> - 1.15-1
- Initial build
